/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.specific;

import java.util.Enumeration;
import java.util.Hashtable;

/**
 * this is a definition of a pool it handles objects and references on it. It is
 * actually just a way to count references on a set of Objects.
 * 
 * @author Sebastien Ponce
 */
public class Pool extends Hashtable {

    /**
     * adds a reference on an Object
     * 
     * @param object the Object to add a reference on
     */
    public void addRef(Object object) {
        if (this.containsKey(object)) {
            this.put(object, new Integer(this.getRefNumber(object) + 1));
        } else {
            this.put(object, new Integer(1));
        }
    }

    /**
     * adds a number of references on an Object
     * 
     * @param object the object to add references on
     * @param nb the number of references
     */
    public void addRef(Object object, int nb) {
        if (this.containsKey(object)) {
            this.put(object, new Integer(this.getRefNumber(object) + nb));
        } else {
            this.put(object, new Integer(nb));
        }
    }

    /**
     * removes a reference on an object
     * 
     * @param object the object to remove
     */
    public void removeRef(Object object) {
        if (this.containsKey(object)) {
            this.put(object, new Integer(this.getRefNumber(object) - 1));
        }
    }

    public Object remove(Object object) {
        return super.remove(object);
    }

    /**
     * returns an enumeration of Objects in this pool
     * 
     * @return an enumeration of Objects in this pool
     */
    public Enumeration getPoolContent() {
        return this.keys();
    }

    /**
     * returns the number of references on a given object
     * 
     * @param object the object concerned
     * @return the number of references on object
     */
    public int getRefNumber(Object object) {
        if (this.containsKey(object)) {
            return ((Integer) this.get(object)).intValue();
        } else {
            return -1;
        }
    }

}