/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.undo;

import org.w3c.dom.Document;

/**
 * this is an extension of the abstract class AbstractUndoableEdit that
 * associates each UndoableEdit to an xml document. This allows to remove some
 * of the Edits while a document is closed.
 */

public abstract class AbstractUndoableEdit extends
        javax.swing.undo.AbstractUndoableEdit implements DocumentUndoableEdit {

    /**
     * the Document this Edit is associated with
     */
    protected Document document;

    /**
     * constructor
     * 
     * @param document the Document this Edit is associated with
     */
    public AbstractUndoableEdit(Document document) {
        super();
        this.document = document;
    }

    /**
     * makes this edit die if it is associated to the Document document. returns
     * true if it died, false if not.
     * 
     * @param document a document
     * @return true if it died, false if not
     */
    public boolean conditionnalDieAndTrim(Document document) {
        if (document == this.document) {
            this.die();
            return true;
        }
        return false;
    }

}