/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese;

import java.awt.Dimension;
import java.io.File;

import javax.swing.DefaultListModel;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import javax.swing.ListSelectionModel;

import com.simulogic.utils.ExceptionDialog;
import com.simulogic.utils.ExtensionFileFilter;

/**
 * Generates dialog box to manage installed and install new models
 */
public class ModelOptions extends javax.swing.JDialog {

	/** A return status code - returned if Cancel button has been pressed */
	public static final int RET_CANCEL = 0;

	/** A return status code - returned if OK button has been pressed */
	public static final int RET_OK = 1;

	private File dir, file;

	private ModelManager manager = CESE.getEnvironment().getModelManager();

	/**
	 * Generates dialog box to manage installed and install new models
	 * 
	 * @param parent
	 *            parent frame
	 */
	public ModelOptions(java.awt.Frame parent) {
		super(parent, true);
		initComponents();
	}

	/**
	 * @return the return status of this dialog - one of RET_OK or RET_CANCEL
	 */
	public int getReturnStatus() {
		return returnStatus;
	}

	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		buttonPanel = new javax.swing.JPanel();
		okButton = new javax.swing.JButton();
		cancelButton = new javax.swing.JButton();
		listPanel = new javax.swing.JPanel();
		listScrollPane = new javax.swing.JScrollPane();
		modelList = new javax.swing.JList();
		modelPanel = new javax.swing.JPanel();
		selectionPanel = new javax.swing.JPanel();
		installButton = new javax.swing.JButton();
		removeButton = new javax.swing.JButton();
		upButton = new javax.swing.JButton();
		downButton = new javax.swing.JButton();

		setTitle(ResourceManager.getResource("Model_Manager"));
		addWindowListener(new java.awt.event.WindowAdapter() {

			public void windowClosing(java.awt.event.WindowEvent evt) {
				closeDialog();
			}
		});

		buttonPanel
				.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

		okButton.setText(ResourceManager.getResource("OK"));
		okButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				okButtonActionPerformed();
			}
		});

		buttonPanel.add(okButton);

		cancelButton.setText(ResourceManager.getResource("Cancel"));
		cancelButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				cancelButtonActionPerformed();
			}
		});

		buttonPanel.add(cancelButton);

		getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

		listPanel.setLayout(new java.awt.BorderLayout());

		listPanel.setBorder(new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder(), ResourceManager
						.getResource("Installed_models")));
		modelList.setCellRenderer(new ModelBoxRenderer(true));
		modelList.setVisibleRowCount(3);
		modelList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

		listScrollPane.setViewportView(modelList);
		listScrollPane.setPreferredSize(new Dimension(250, 150));

		listPanel.add(listScrollPane, java.awt.BorderLayout.CENTER);

		modelPanel.add(listPanel, java.awt.BorderLayout.CENTER);

		selectionPanel.setLayout(new java.awt.GridBagLayout());

		installButton.setMnemonic('i');
		installButton.setText(ResourceManager.getResource("Install_Model..."));
		installButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				installButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(20, 5, 10, 5);
		selectionPanel.add(installButton, gridBagConstraints);

		removeButton.setMnemonic('r');
		removeButton.setText(ResourceManager.getResource("Remove_Model"));
		removeButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				removeButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(10, 5, 10, 5);
		selectionPanel.add(removeButton, gridBagConstraints);

		upButton.setMnemonic('u');
		upButton.setText(ResourceManager.getResource("Move_up"));
		upButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				upButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(10, 5, 10, 5);
		selectionPanel.add(upButton, gridBagConstraints);

		downButton.setMnemonic('d');
		downButton.setText(ResourceManager.getResource("Move_down"));
		downButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				downButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 3;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(10, 5, 20, 5);
		selectionPanel.add(downButton, gridBagConstraints);

		modelPanel.add(selectionPanel, java.awt.BorderLayout.EAST);

		getContentPane().add(modelPanel, java.awt.BorderLayout.CENTER);
	}

	private void cancelButtonActionPerformed() {
		doClose(RET_CANCEL);
	}

	private void okButtonActionPerformed() {
		manager.getSelector().removeAllItems();
		for (int i = 0; i < modelList.getModel().getSize(); i++) {
			manager.getSelector().addItem(modelList.getModel().getElementAt(i));
			((ModelInfo) modelList.getModel().getElementAt(i))
					.addPropertyChangeListener(manager);
		}
		doClose(RET_OK);
	}

	private void upButtonActionPerformed() {
		int current = modelList.getSelectedIndex();
		if (current > 0) {
			Object item = ((DefaultListModel) modelList.getModel())
					.remove(current);
			((DefaultListModel) modelList.getModel()).insertElementAt(item,
					current - 1);
		}
	}

	private void downButtonActionPerformed() {
		int current = modelList.getSelectedIndex();
		if ((current < modelList.getModel().getSize() - 1) && (current >= 0)) {
			Object item = ((DefaultListModel) modelList.getModel())
					.remove(current);
			((DefaultListModel) modelList.getModel()).insertElementAt(item,
					current + 1);
		}
	}

	private void removeButtonActionPerformed() {
		int current = modelList.getSelectedIndex();
		if ((modelList.getModel().getSize() > 0) && (current >= 0))
			((DefaultListModel) modelList.getModel()).remove(current);
	}

	private void installButtonActionPerformed() {
		dir = new File(UserHome.CESE_HOME + UserHome.FS
				+ ResourceManager.getResource("mods_dir"));

		try {
			JFileChooser filechooser = new JFileChooser(dir);
			filechooser.setDialogTitle(ResourceManager
					.getResource("Install_Model"));
			filechooser.setApproveButtonMnemonic('I');
			filechooser.setApproveButtonToolTipText(ResourceManager
					.getResource("Install_model"));
			ExtensionFileFilter preferredFilter = new ExtensionFileFilter(
					"jar", ResourceManager.getResource("Model_Code_Files"));
			filechooser.addChoosableFileFilter(preferredFilter);
			filechooser.setFileFilter(preferredFilter);

			int retVal = filechooser.showDialog(CESE.getEnvironment(),
					ResourceManager.getResource("Install"));
			if (retVal == JFileChooser.APPROVE_OPTION) {
				file = filechooser.getSelectedFile();
				dir = filechooser.getCurrentDirectory();
				if (file.getPath() == null)
					return;
				
				ModelInstaller modelInstaller = new ModelInstaller();
				modelInstaller.addJarFile(file.getPath());

				int installed = modelInstaller.getInstalledModels().size();
				if (installed > 0) {
					for (int i = 0; i < installed; i++) {
						((DefaultListModel) modelList.getModel())
								.addElement(modelInstaller.getInstalledModels()
										.get(i));
					}
				}

				diagnoseInstall(modelInstaller);
			}
		} catch (Exception e) {
			ExceptionDialog.showExceptionDialog(ResourceManager
					.getResource("Error"), ResourceManager
					.getResource("Error_installing_model."), e);
		}
	}

	private void diagnoseInstall(ModelInstaller mi) {
		String diagnoseString = "";
		int installed = mi.getInstalledNames().size();
		if (installed == 0) {
			ExceptionDialog.showExceptionDialog(ResourceManager
					.getResource("Installation_error"), ResourceManager
					.getResource("No_valid_models_found."), null);
		} else {
			for (int i = 0; i < installed; i++) {
				diagnoseString += (String) mi.getInstalledNames().get(i) + '\n';
			}
			JOptionPane.showMessageDialog(CESE.getEnvironment(), installed
					+ " " + ResourceManager.getResource("model(s)_installed")
					+ '\n' + diagnoseString, ResourceManager
					.getResource("Installation_complete"),
					JOptionPane.INFORMATION_MESSAGE);
		}
	}

	private void setList() {
		modelList.setModel(new DefaultListModel());
		for (int i = 0; i < manager.getSelector().getModel().getSize(); i++) {
			((DefaultListModel) modelList.getModel()).addElement(manager
					.getSelector().getModel().getElementAt(i));
		}
	}

	private void doClose(int retStatus) {
		returnStatus = retStatus;
		setVisible(false);
		dispose();
	}

	/**
	 * Closes the dialog
	 */
	private void closeDialog() {
		doClose(RET_CANCEL);
	}

	/**
	 * Overrides setVisible(boolean b) in <code>JDialog</code>
	 * 
	 * @param b
	 *            visibility
	 */
	public void setVisible(boolean b) {
		if (b == true) {
			setResizable(true);
			setList();
			pack();
			setResizable(false);
			getRootPane().setDefaultButton(okButton);
			setLocationRelativeTo(getOwner());
		}
		super.setVisible(b);
	}

	private javax.swing.JPanel listPanel;

	private javax.swing.JPanel buttonPanel;

	private javax.swing.JList modelList;

	private javax.swing.JPanel modelPanel;

	private javax.swing.JButton okButton;

	private javax.swing.JButton cancelButton;

	private javax.swing.JButton installButton;

	private javax.swing.JPanel selectionPanel;

	private javax.swing.JButton upButton;

	private javax.swing.JButton downButton;

	private javax.swing.JScrollPane listScrollPane;

	private javax.swing.JButton removeButton;

	private int returnStatus = RET_CANCEL;

}