/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.signals;

/**
 * This is a class for creating a level signal
 * <p>
 * 2 parameters for level signal:
 * <ol>
 * <li>is an amplitude
 * <li>is a duration
 * </ol>
 */
public class LevelSignal extends AbstractSignal {

    /**
     * Creates new level signal
     */
    public LevelSignal() {
        maxParams = 2;
    }

    /**
     * Builds the signal array
     * 
     * @param dt current sampling step, i.e. distance between 2 data points
     * @return resulting array with signal data
     */
    public double[] buildSignal(double dt) {
        double level, duration;
        double[] result = null;

        try {
            level = ((Double) parameters.get(0)).doubleValue();
            duration = ((Double) parameters.get(1)).doubleValue();

            if (duration <= 0) return result;

            duration = duration / dt;
            int steps = (int) Math.round(duration);
            result = new double[steps];
            int count = 0;

            while (count < steps) {
                result[count] = level;
                count++;
            }
        } catch (Exception e) {
        }
        return result;
    }

}