/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import javax.swing.JTabbedPane;

/**
 * Frame that contains data and analysis results
 */
public class DataFrame extends javax.swing.JInternalFrame {

	private JTabbedPane content;

	private ViewContent dataContent = null;

	private ViewContent ivContent = null;

	private ViewContent statContent = null;

	private int number;

	/**
	 * Creates new DataFrame
	 * 
	 * @param desktop
	 *            desktop
	 * @param title
	 *            title of this frame
	 */
	public DataFrame(String title, DataDesktop desktop) {
		super(title);

		setIconifiable(true);
		setMaximizable(true);
		setResizable(true);
		setClosable(true);

		this
				.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		getContentPane().setLayout(new java.awt.BorderLayout());

		content = new javax.swing.JTabbedPane();
		content.setTabPlacement(javax.swing.SwingConstants.TOP);
		setDataContent(new ViewContent());
		getContentPane().add(content, "Center");

		this.addInternalFrameListener(desktop);
		pack();
	}

	/**
	 * Returns a currently selected content
	 * 
	 * @return selected content
	 */
	public ViewContent getSelectedContent() {
		return (ViewContent) content.getSelectedComponent();
	}

	/**
	 * Sets selected content
	 * 
	 * @param c
	 *            content
	 */
	public void setSelectedContent(ViewContent c) {
		try {
			content.setSelectedComponent(c);
		} catch (Exception e) {
		}
	}

	/**
	 * Returns a data content
	 * 
	 * @return data content
	 */
	public ViewContent getDataContent() {
		return dataContent;
	}

	/**
	 * Sets data content
	 * 
	 * @param v
	 *            view content for data
	 */
	public void setDataContent(ViewContent v) {
		if (v != null) {
			if (dataContent == null) {
				content.addTab(ResourceManager.getResource("Results"), v);
			} else {
				content
						.setComponentAt(content.indexOfComponent(dataContent),
								v);
			}

			v.getView().getCursors().getCursorSlider().setVisible(true);
			v.getView().setClipping(DataView.VIEW_CLIP);
			dataContent = v;
			content.setSelectedComponent(dataContent);
		}
	}

	/**
	 * Returns IV content
	 * 
	 * @return IV content
	 */
	public ViewContent getIVContent() {
		return ivContent;
	}

	/**
	 * Sets IV content
	 * 
	 * @param v
	 *            view content for IV
	 */
	public void setIVContent(ViewContent v) {
		if (v != null) {
			if (ivContent == null) {
				content.addTab(ResourceManager.getResource("IV"), v);
			} else {
				content.setComponentAt(content.indexOfComponent(ivContent), v);
			}

			v.getView().getCursors().getCursorSlider().setVisible(false);
			v.getView().setClipping(DataView.NO_CLIP);
			v.getView().getXAxis().setZeroCross(true);
			v.getView().getYAxis().setZeroCross(true);

			ivContent = v;
		}
	}

	/**
	 * Returns a stats content
	 * 
	 * @return stats content
	 */
	public ViewContent getStatsContent() {
		return statContent;
	}

	/**
	 * Sets stats content
	 * 
	 * @param v
	 *            view content for stats
	 */
	public void setStatsContent(ViewContent v) {
		if (v != null) {
			if (statContent == null) {
				content.addTab(ResourceManager.getResource("Statistics"), v);
			} else {
				content
						.setComponentAt(content.indexOfComponent(statContent),
								v);
			}
			v.getTabs().removeTabAt(v.getTabs().indexOfTab(ResourceManager.getResource("Cursors")));
			v.getTabs().removeTabAt(v.getTabs().indexOfTab(ResourceManager.getResource("Plot")));
			v.getView().getCursors().getCursorSlider().setVisible(false);

			statContent = v;
		}
	}

	/**
	 * Finishes data loading
	 * 
	 * @param group
	 *            new group to add
	 */
	public synchronized void finishLoad(final DataGroup group) {
		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {

				getDataContent().getStorage().addGroup(group);

				try {
					setClosable(true);

					if (!isShowing()) {
						setSize(300, 300);

						if ((isMaximizable()) && (!isMaximum())) {
							setMaximum(true);
						}
						show();
						getDataContent().getView().renderPlot();
					}
				} catch (java.beans.PropertyVetoException ev) {
				}
			}
		});
	}

	public String getTitle() {
		return(super.getTitle() + " <" + number + "> ");
	}

	/**
	 * Sets frame number
	 * 
	 * @param number
	 *            the frame number to set
	 */
	public void setNumber(int number) {
		this.number = number;
	}

	/**
	 * Returns frame number
	 * 
	 * @return the frame number
	 */
	public int getNumber() {
		return number;
	}

}