/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview;

import java.beans.PropertyVetoException;
import java.util.Vector;

/**
 * Generates dialog box to show list of windows in the desktop
 */
public class WindowList extends javax.swing.JDialog {

	/** A return status code - returned if Cancel button has been pressed */
	public static final int RET_CANCEL = 0;

	/** A return status code - returned if OK button has been pressed */
	public static final int RET_OK = 1;

	private DataDesktop desktop;

	/**
	 * Generates dialog with window list and common window actions
	 * 
	 * @param parent
	 *            parent frame
	 * @param d
	 *            desktop
	 */
	public WindowList(java.awt.Frame parent, DataDesktop d) {
		super(parent, true);
		desktop = d;
		initComponents();
	}

	/**
	 * @return the return status of this dialog - one of RET_OK or RET_CANCEL
	 */
	public int getReturnStatus() {
		return returnStatus;
	}

	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		buttonPanel = new javax.swing.JPanel();
		okButton = new javax.swing.JButton();
		cancelButton = new javax.swing.JButton();
		windowPanel = new javax.swing.JPanel();
		listPanel = new javax.swing.JPanel();
		listScrollPane = new javax.swing.JScrollPane();
		windowList = new javax.swing.JList();
		selectionPanel = new javax.swing.JPanel();
		activateButton = new javax.swing.JButton();
		closeAllButton = new javax.swing.JButton();
		closeButton = new javax.swing.JButton();

		setTitle(ResourceManager.getResource("Window_List"));
		addWindowListener(new java.awt.event.WindowAdapter() {

			public void windowClosing(java.awt.event.WindowEvent evt) {
				closeDialog();
			}
		});

		buttonPanel
				.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

		okButton.setText(ResourceManager.getResource("OK"));
		okButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				okButtonActionPerformed();
			}
		});

		buttonPanel.add(okButton);

		cancelButton.setText(ResourceManager.getResource("Cancel"));
		cancelButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				cancelButtonActionPerformed();
			}
		});

		// buttonPanel.add(cancelButton);

		getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

		windowPanel.setLayout(new java.awt.BorderLayout());

		listPanel.setLayout(new java.awt.BorderLayout());

		listPanel.setBorder(new javax.swing.border.TitledBorder(
				new javax.swing.border.EtchedBorder()));
		listPanel.setPreferredSize(new java.awt.Dimension(271, 155));
		listPanel.setMinimumSize(new java.awt.Dimension(271, 155));

		listScrollPane.setViewportView(windowList);

		listPanel.add(listScrollPane, java.awt.BorderLayout.CENTER);

		windowPanel.add(listPanel, java.awt.BorderLayout.CENTER);

		selectionPanel.setLayout(new java.awt.GridBagLayout());

		activateButton.setMnemonic('a');
		activateButton.setText(ResourceManager.getResource("Activate"));
		activateButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				activateButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(20, 5, 10, 5);
		selectionPanel.add(activateButton, gridBagConstraints);

		closeButton.setMnemonic('c');
		closeButton.setText(ResourceManager.getResource("Close"));
		closeButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				closeButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(10, 5, 10, 5);
		selectionPanel.add(closeButton, gridBagConstraints);

		closeAllButton.setMnemonic('l');
		closeAllButton.setText(ResourceManager.getResource("Close_all"));
		closeAllButton.addActionListener(new java.awt.event.ActionListener() {

			public void actionPerformed(java.awt.event.ActionEvent evt) {
				closeAllButtonActionPerformed();
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(10, 5, 20, 5);
		selectionPanel.add(closeAllButton, gridBagConstraints);

		windowPanel.add(selectionPanel, java.awt.BorderLayout.EAST);

		getContentPane().add(windowPanel, java.awt.BorderLayout.CENTER);
	}

	private void cancelButtonActionPerformed() {
		doClose(RET_CANCEL);
	}

	private void okButtonActionPerformed() {

		doClose(RET_OK);
	}

	private void activateButtonActionPerformed() {
		if (windowList.getSelectedIndex() != -1) {
			DataFrame frame = (DataFrame) desktop.getAllFrames()[windowList
					.getSelectedIndex()];
			frame.moveToFront();
			try {
				frame.setSelected(true);
			} catch (PropertyVetoException e) {
			}

			setWindows();
		}
	}

	private void closeButtonActionPerformed() {
		if (windowList.getSelectedIndex() != -1) {
			DataFrame frame = (DataFrame) desktop.getAllFrames()[windowList
					.getSelectedIndex()];

			if ((frame != null) && (frame.isClosable()))
				try {
					frame.setClosed(true);
				} catch (java.beans.PropertyVetoException ev) {
				}

			setWindows();
		}
	}

	private void closeAllButtonActionPerformed() {
		desktop.closeAllFrames();

		setWindows();
	}

	private void doClose(int retStatus) {
		returnStatus = retStatus;
		setVisible(false);
		dispose();
	}

	/** Closes the dialog */
	private void closeDialog() {
		doClose(RET_CANCEL);
	}

	/**
	 * Overrides setVisible(boolean b) in <code>JDialog</code>
	 */
	public void setVisible(boolean b) {
		if (b == true) {
			setWindows();

			setResizable(true);
			pack();
			setResizable(false);
			getRootPane().setDefaultButton(okButton);
			setLocationRelativeTo(getOwner());
		}
		super.setVisible(b);
	}

	private void setWindows() {
		Vector names = new Vector();
		Vector frames = desktop.getDataFrames();
		if (frames != null) {
			for (int i = 0; i < frames.size(); i++) {
				names.add(((DataFrame) frames.get(i)).getTitle());
			}
		}
		windowList.setListData(names);
	}

	private javax.swing.JPanel listPanel;

	private javax.swing.JPanel buttonPanel;

	private javax.swing.JList windowList;

	private javax.swing.JPanel windowPanel;

	private javax.swing.JButton okButton;

	private javax.swing.JButton cancelButton;

	private javax.swing.JButton activateButton;

	private javax.swing.JButton closeButton;

	private javax.swing.JButton closeAllButton;

	private javax.swing.JScrollPane listScrollPane;

	private javax.swing.JPanel selectionPanel;

	private int returnStatus = RET_CANCEL;

}